/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 1997-2006.
 *
 * Licensed under the Aduna BSD-style license.
 */
 
package org.slf4j;

import junit.framework.TestCase;

/**
 * Test whether invoking the SLF4J API causes problems or not.
 * 
 * @author Ceki Gulcu
 * 
 */
public class InvocationTest extends TestCase {

	public InvocationTest(String arg0) {
		super(arg0);
	}

	protected void setUp() throws Exception {
		super.setUp();
	}

	protected void tearDown() throws Exception {
		super.tearDown();
	}

	public void test1() {
		Logger logger = LoggerFactory.getLogger("test1");
		logger.debug("Hello world.");
	}

	public void test2() {
		Integer i1 = new Integer(1);
		Integer i2 = new Integer(2);
		Integer i3 = new Integer(3);
		Exception e = new Exception("This is a test exception.");
		Logger logger = LoggerFactory.getLogger("test2");

		logger.debug("Hello world 1.");
		logger.debug("Hello world {}", i1);
		logger.debug("val={} val={}", i1, i2);
		logger.debug("val={} val={} val={}", new Object[] { i1, i2, i3 });

		logger.debug("Hello world 2", e);
		logger.info("Hello world 2.");

		logger.warn("Hello world 3.");
		logger.warn("Hello world 3", e);

		logger.error("Hello world 4.");
		logger.error("Hello world {}", new Integer(3));
		logger.error("Hello world 4.", e);
	}

	public void testNull() {
		Logger logger = LoggerFactory.getLogger("testNull");
		logger.debug(null);
		logger.info(null);
		logger.warn(null);
		logger.error(null);

		Exception e = new Exception("This is a test exception.");
		logger.debug(null, e);
		logger.info(null, e);
		logger.warn(null, e);
		logger.error(null, e);
	}

	public void testMarker() {
		Logger logger = LoggerFactory.getLogger("testMarker");
		Marker blue = MarkerFactory.getMarker("BLUE");
		logger.debug(blue, "hello");
		logger.info(blue, "hello");
		logger.warn(blue, "hello");
		logger.error(blue, "hello");

		logger.debug(blue, "hello {}", "world");
		logger.info(blue, "hello {}", "world");
		logger.warn(blue, "hello {}", "world");
		logger.error(blue, "hello {}", "world");

		logger.debug(blue, "hello {} and {} ", "world", "universe");
		logger.info(blue, "hello {} and {} ", "world", "universe");
		logger.warn(blue, "hello {} and {} ", "world", "universe");
		logger.error(blue, "hello {} and {} ", "world", "universe");
	}
}
